@@ -7,7 +7,7 @@ import (
 	"strings"
 	"syscall"
 
-	"kernel.org/pub/linux/libs/security/libcap/cap"
+	"libcap/cap"
 )
 
 // tryLaunching attempts to launch a bunch of programs in parallel. It
@@ -20,8 +20,6 @@ func tryLaunching() {
 	}
 	root := cwd[:strings.LastIndex(cwd, "/")]
 
-	hasSysAdmin, _ := cap.GetBound(cap.SYS_ADMIN)
-
 	vs := []struct {
 		args       []string
 		fail       bool
@@ -30,28 +28,22 @@ func tryLaunching() {
 		iab        string
 		uid        int
 		gid        int
-		mode       cap.Mode
 		groups     []int
 	}{
 		{args: []string{root + "/go/ok"}},
 		{
-			args:   []string{root + "/progs/tcapsh-static", "--dropped=cap_chown", "--is-uid=123", "--is-gid=456", "--has-a=cap_setuid"},
+			args:   []string{root + "/progs/capsh", "--dropped=cap_chown", "--is-uid=123", "--is-gid=456", "--has-a=cap_setuid"},
 			iab:    "!cap_chown,^cap_setuid,cap_sys_admin",
 			uid:    123,
 			gid:    456,
 			groups: []int{1, 2, 3},
-			fail:   syscall.Getuid() != 0 || !hasSysAdmin,
+			fail:   syscall.Getuid() != 0,
 		},
 		{
 			args:   []string{"/ok"},
 			chroot: root + "/go",
 			fail:   syscall.Getuid() != 0,
 		},
-		{
-			args: []string{root + "/progs/tcapsh-static", "--inmode=NOPRIV", "--has-no-new-privs"},
-			mode: cap.ModeNoPriv,
-			fail: syscall.Getuid() != 0,
-		},
 	}
 
 	ps := make([]int, len(vs))
@@ -69,9 +61,6 @@ func tryLaunching() {
 		if v.gid != 0 {
 			e.SetGroups(v.gid, v.groups)
 		}
-		if v.mode != 0 {
-			e.SetMode(v.mode)
-		}
 		if v.iab != "" {
 			if iab, err := cap.IABFromText(v.iab); err != nil {
 				log.Fatalf("failed to parse iab=%q: %v", v.iab, err)
@@ -79,7 +68,6 @@ func tryLaunching() {
 				e.SetIAB(iab)
 			}
 		}
-		log.Printf("[%d] trying: %q\n", i, v.args)
 		if ps[i], err = e.Launch(nil); err != nil {
 			if v.fail {
 				continue
